#
# spec file for package php8-pear
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global peardir %{_datadir}/php/PEAR
%global oldpear %{_datadir}/php7/PEAR
%global metadir %{_localstatedir}/lib/pear

%define pear_module_version(m) %(sed -n 's/.*=>.*%{1}-\\(.*\\)\\.tar.*/\\1/p' %{SOURCE0})

Name:           php8-pear
Version:        1.10.22
Release:        1.1
Summary:        PHP Extension and Application Repository
License:        BSD-2-Clause
Group:          Development/Libraries/PHP
URL:            https://pear.php.net/package/pearweb_phars
Source0:        https://github.com/pear/pearweb_phars/raw/v%{version}/install-pear-nozlib.phar
Source1:        https://github.com/pear/pearweb_phars/raw/v%{version}/install-pear-nozlib.sig#/install-pear-nozlib.phar.sig
Source2:        %{name}.keyring
Source3:        %{name}.rpmlintrc
BuildRequires:  php8-cli
BuildRequires:  php8-phar
Requires:       php8-cli
Requires:       php8-openssl
Requires:       php8-phar
Provides:       php-pear(Archive_Tar) = %pear_module_version Archive_Tar
Provides:       php-pear(Console_Getopt) = %pear_module_version Console_Getopt
Provides:       php-pear(PEAR) = %pear_module_version PEAR
Provides:       php-pear(Structures_Graph) = %pear_module_version Structures_Graph
Provides:       php-pear(XML_Util) = %pear_module_version XML_Util
Provides:       php-pear = %{version}
Obsoletes:      php-pear < %{version}
Conflicts:      php7-pear
BuildArch:      noarch

%description
PEAR is a code repository for PHP extensions and PHP library code
similar to TeX's CTAN and Perl's CPAN. This package provides an access
to the repository.

See https://pear.php.net/manual for more details.

%package -n php8-pecl
Summary:        PHP Extension Community Library
Group:          Development/Libraries/PHP
Requires:       autoconf
Requires:       automake
Requires:       gcc-c++
Requires:       libtool
Requires:       php8-pear = %{version}
Provides:       php-pecl = %{version}
Obsoletes:      php-pecl < %{version}
Conflicts:      php7-pecl
BuildArch:      noarch

%description -n php8-pecl
PECL is a repository for PHP Extensions, providing a directory of
all known extensions and hosting facilities for downloading and
development of PHP extensions.

See https://pecl.php.net for more details.

%prep
# Empty prep section, nothing to prepare

%build
# Empty build section, nothing to build

%install
export PHP_PEAR_INSTALL_DIR=%{peardir}
export PHP_PEAR_METADATA_DIR=%{metadir}
export PHP_PEAR_SIG_BIN=%{_bindir}/gpg
export PHP_PEAR_SYSCONF_DIR=%{_sysconfdir}/php8/cli
export INSTALL_ROOT=%{buildroot}

install -d %{buildroot}%{_localstatedir}/{cache,lib}/pear

php -d date.timezone=UTC -d memory_limit=64M -d short_open_tag=0 -d safe_mode=0 \
	-d 'error_reporting=E_ALL&~E_DEPRECATED' -d detect_unicode=0 %{SOURCE0} \
	--force \
	--bin      %{_bindir} \
	--cache    %{_localstatedir}/cache/pear \
	--dir      %{peardir} \
	--man      %{_mandir} \
	--metadata %{metadir} \
	--www      %{peardir}/htdocs

%pre
if [ -d %{oldpear}/.registry -a ! -d %{metadir}/.registry ]; then
    mkdir -p %{metadir}
    cp -af %{oldpear}/{.channels,.registry} %{metadir}
fi
if [ -d %{oldpear} -a ! -d %{peardir} ]; then
    mkdir -p %{peardir}
    cp -af %{oldpear}/* %{peardir}
fi

%posttrans
mdir=$(%{_bindir}/pear config-get metadata_dir system)
if [ "${mdir}" != "%{metadir}" -a -d %{metadir}/.registry ]; then
    %{_bindir}/pear config-set metadata_dir %{metadir} system
    rm -rf %{oldpear}/{.channels,.registry}
fi

%files
%{_bindir}/pear
%config(noreplace) %{_sysconfdir}/php8/cli/pear.conf
%dir %{_localstatedir}/cache/pear
%dir %{_localstatedir}/lib/pear
%dir %{peardir}
%docdir %{peardir}/doc
%{peardir}/*
%{metadir}/.??*
%exclude %{_bindir}/peardev
%exclude %{peardir}/doc/PEAR/INSTALL
%exclude %{peardir}/test

%files -n php8-pecl
%{_bindir}/pecl

%changelog
* Sun Nov 26 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.10.22
  - PEAR 1.10.14
  * Put glue and pieces parameters to implode in correct order for
    PHP 7.4+
  * Fix PHP bug 81653: Typo in install-pear-nozlib.phar
  * Add %%S EXPECTF capability
  * Fix: Creation of dynamic property PEAR_Error::$callback is
    deprecated
  * Fixed extension loaded check for pecl binaries
  * Remove -n option from pecl.bat for shared extensions
  * Fix Using ${var} in strings is deprecated
  * Fix lingering license references to PHP license
  * Exclude tests from composer classmap
  * Fix private lastError name
* Wed Aug 11 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.10.21
  - PEAR 1.10.13
  * unsupported protocol - use --force to continue
  * Add $this operator to _determineIfPowerpc calls
- Update to 1.10.20
  - Archive_Tar 1.4.14
  * Properly fix symbolic link path traversal (CVE-2021-32610)
  - Archive_Tar 1.4.13
  * Relative symlinks failing (out-of path file extraction)
  - Archive_Tar 1.4.12
  - Archive_Tar 1.4.11
  - Archive_Tar 1.4.10
  * Fix block padding when the file buffer length is a multiple
    of 512 and smaller than Archive_Tar buffer length
  * Don't try to copy username/groupname in chroot jail
* Wed Jan 20 2021 Arjen de Korte <suse+build@de-korte.org>
- Conflicts with php7-pear and php7-pecl
* Tue Jan 12 2021 Arjen de Korte <suse+build@de-korte.org>
- (Build)Require php8-cli instead of php8
* Sat Jan  9 2021 Arjen de Korte <suse+build@de-korte.org>
- Build for PHP8
* Tue May 19 2020 pgajdos@suse.com
- provides and obsoletes php7-pear-Archive_Tar, former location
  of PEAR/Archive/Tar.php
* Sun Apr 19 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.10.19
  - PEAR 1.10.12
  * adjust dependencies based on new releases
  - XML_Util 1.4.5
  * fix Trying to access array offset on value of type int
* Fri Apr 10 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.10.18
- Remove pear-cacheid-array-check.patch (upstreamed)
- Contents of .filemap are now sorted internally
* Fri Feb 28 2020 Arjen de Korte <suse+build@de-korte.org>
- Sort contents of .filemap to make build reproducible
* Sat Dec  7 2019 Arjen de Korte <suse+build@de-korte.org>
- Apply upstream patch for https://bugs.php.net/78890
  + pear-cacheid-array-check.patch
- Recommend php7-openssl to allow https sources to be used
- Modify metadata_dir for system configuration only
- Add /var/lib/pear directory where xml files are stored
- Cleanup %%files section
* Tue Nov 26 2019 Arjen de Korte <suse+build@de-korte.org>
- Only use the GPG keys of Chuck Burgess. Extracted from the
  Release Manager public keys.
- Add release versions of PEAR modules
* Tue Nov 26 2019 Arjen de Korte <suse+build@de-korte.org>
- Install metadata files (registry, filemap, channels, ...) in
  /var/lib/pear/ instead of /usr/share/php7/PEAR/
* Mon Nov 25 2019 Arjen de Korte <suse+build@de-korte.org>
- Create php7-pecl subpackage for PECL builds
* Sat Nov 23 2019 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.10.17
- Package separately, as builtin PEAR was deprecated in PHP-7.4
